@@ -14,12 +14,12 @@
 
 namespace cln {
 
-const cl_FF scale_float (const cl_FF& x, sintL delta)
+const cl_FF scale_float (const cl_FF& x, sintC delta)
 {
   // Methode:
   // x=0.0 -> x als Ergebnis
-  // delta mu betragsmig <= FF_exp_high-FF_exp_low sein.
-  // Neues FF mit um delta vergrertem Exponenten bilden.
+  // delta muß betragsmäßig <= FF_exp_high-FF_exp_low sein.
+  // Neues FF mit um delta vergrößertem Exponenten bilden.
       // x entpacken:
       var cl_signean sign;
       var sintL exp;
@@ -27,24 +27,24 @@ const cl_FF scale_float (const cl_FF& x, sintL delta)
       FF_decode(x, { return x; }, sign=,exp=,mant=);
       if (delta >= 0)
         // delta>=0
-        { var uintL udelta = delta;
+        { var uintC udelta = delta;
           if (udelta <= (uintL)(FF_exp_high-FF_exp_low))
             { exp = exp+udelta;
               return encode_FF(sign,exp,mant);
             }
             else
-            { cl_error_floating_point_overflow(); }
+            { throw floating_point_overflow_exception(); }
         }
         else
         // delta<0
-        { var uintL udelta = -delta;
+        { var uintC udelta = -delta;
           if (udelta <= (uintL)(FF_exp_high-FF_exp_low))
             { exp = exp-udelta;
               return encode_FF(sign,exp,mant);
             }
             else
             if (underflow_allowed())
-              { cl_error_floating_point_underflow(); }
+              { throw floating_point_underflow_exception(); }
               else
               { return cl_FF_0; }
         }
