@@ -11,8 +11,7 @@
 
 #include "cl_F.h"
 
-#undef MAYBE_INLINE
-#define MAYBE_INLINE inline
+#include "cl_inline.h"
 #include "cl_SF_idecode.cc"
 #include "cl_FF_idecode.cc"
 #include "cl_DF_idecode.cc"
@@ -20,13 +19,13 @@
 
 namespace cln {
 
-const cl_idecoded_float integer_decode_float (const cl_F& x)
+const cl_idecoded_float CL_FLATTEN integer_decode_float (const cl_F& x)
 {
 	floatcase(x
-	,	return integer_decode_float(x);
-	,	return integer_decode_float(x);
-	,	return integer_decode_float(x);
-	,	return integer_decode_float(x);
+	,	return integer_decode_float_inline(x);
+	,	return integer_decode_float_inline(x);
+	,	return integer_decode_float_inline(x);
+	,	return integer_decode_float_inline(x);
 	);
 }
 
