@@ -19,7 +19,7 @@ CL_PROVIDE(cl_F_mostpos)
 
 namespace cln {
 
-// Exponent so gro wie mglich, Mantisse 1...1, Vorzeichen +.
+// Exponent so groß wie möglich, Mantisse 1...1, Vorzeichen +.
 
 static const cl_SF most_positive_SF =
 	make_SF(0,SF_exp_high,bit(SF_mant_len+1)-1);
@@ -43,7 +43,7 @@ inline const cl_LF most_positive_LF (uintC len)
 
 const cl_F most_positive_float (float_format_t f)
 {
-	floatformatcase((uintL)f
+	floatformatcase((uintC)f
 	,	return most_positive_SF;
 	,	return most_positive_FF;
 	,	return most_positive_DF;
