@@ -16,15 +16,15 @@
 namespace cln {
 
 // Logische Operationen auf Integers:
-// Methode: aus den Lngen der beiden Argumente eine obere Schranke fr
-// die Lnge des Ergebnisses berechnen (das Maximum der beiden Lngen und
-// FN_maxlength), so da das MSD fr unendlich viele Bits steht.
-// Dann beide Argumente in gleichgroe Digit sequences umwandeln, Operation
-// mit einer einfachen Schleife durchfhren.
+// Methode: aus den Längen der beiden Argumente eine obere Schranke für
+// die Länge des Ergebnisses berechnen (das Maximum der beiden Längen und
+// FN_maxlength), so daß das MSD für unendlich viele Bits steht.
+// Dann beide Argumente in gleichgroße Digit sequences umwandeln, Operation
+// mit einer einfachen Schleife durchführen.
 
 const cl_I logior (const cl_I& x, const cl_I& y)
     { if (fixnump(x) && fixnump(y)) // Beides Fixnums -> ganz einfach:
-        { // bitweise als Fixnum zurck
+        { // bitweise als Fixnum zurück
           return cl_I_from_word(x.word | y.word);
         }
         else
@@ -37,7 +37,7 @@ const cl_I logior (const cl_I& x, const cl_I& y)
          {var uintD* xptr; I_to_DS_n(x,n,xptr=); // Pointer in DS zu x
           var uintD* yptr; I_to_DS_n(y,n,yptr=); // Pointer in DS zu y
           var uintD* zptr = xptr; // Pointer aufs Ergebnis
-          or_loop_msp(xptr,yptr,n); // mit OR verknpfen
+          or_loop_msp(xptr,yptr,n); // mit OR verknüpfen
           return DS_to_I(zptr,n); // Ergebnis als Integer
     }   }}
 
