@@ -21,7 +21,7 @@ const cl_I exquopos (const cl_I& x, const cl_I& y)
 // Falls r<>0, Error.
 // Liefere q.
   var cl_I_div_t q_r = cl_divide(x,y);
-  if (!zerop(q_r.remainder)) { cl_error_exquo(x,y); }
+  if (!zerop(q_r.remainder)) { throw exquo_exception(x,y); }
   return q_r.quotient;
 }
 
