@@ -24,23 +24,28 @@ namespace cln {
 //   Sei n = ord2(x). Dann ist lognot(logior(x,-x)) = 2^n-1.
 //   Also  (ord2 x) = (integer-length (lognot (logior x (- x)))) .
 // Methode 2:
-//   Nullbits am Schlu von x abzhlen:
-//   (ord2 x) = intDsize * Anzahl der Nulldigits am Schlu
+//   Nullbits am Schluß von x abzählen:
+//   (ord2 x) = intDsize * Anzahl der Nulldigits am Schluß
 //              + Anzahl der Nullbits am Ende des letzten Digits /=0.
 
-uintL ord2 (const cl_I& x) // x /= 0
+uintC ord2 (const cl_I& x) // x /= 0
 {
 	if (fixnump(x))
-	  { var uint32 x_ = FN_to_L(x); // x als 32-Bit-Zahl
-	    ord2_32(x_,return);
+	  { var uintV x_ = FN_to_V(x); // x als intVsize-Bit-Zahl
+            // This assumes cl_value_len <= intVsize.
+            #if (intVsize>32)
+	    ord2_64(x_,return);
+            #else
+            ord2_32(x_,return);
+            #endif
 	  }
 	  else
-	  { var uintL bitcount = 0;
+	  { var uintC bitcount = 0;
 	    var const uintD* ptr;
 	    BN_to_NDS_nocopy(x, ,,ptr=); // normalisierte DS zu x bilden.
-	    while (lspref(ptr,0) == 0) { lsshrink(ptr); bitcount += intDsize; } // Nulldigits abzhlen
+	    while (lspref(ptr,0) == 0) { lsshrink(ptr); bitcount += intDsize; } // Nulldigits abzählen
 	    var uintD lsd = lspref(ptr,0); // letztes Digit /=0
-	    ord2_D(lsd,bitcount +=); // dessen Nullbits abzhlen
+	    ord2_D(lsd,bitcount +=); // dessen Nullbits abzählen
 	    return bitcount;
           }
 }
