@@ -9,19 +9,21 @@
 
 // Implementation.
 
+#include <sstream>
 #include "cln/integer.h"
 #include "cln/integer_io.h"
-#include "cln/abort.h"
+#include "cln/exception.h"
 
 namespace cln {
 
 void format_old_roman (std::ostream& stream, const cl_I& arg)
 {
 	if (!(0 < arg && arg < 5000)) {
-		fprint(std::cerr, "format_old_roman: argument should be in the range 1 - 4999, not ");
-		fprint(std::cerr, arg);
-		fprint(std::cerr, ".\n");
-		cl_abort();
+		std::ostringstream buf;
+		fprint(buf, "format_old_roman: argument should be in the range 1 - 4999, not ");
+		fprint(buf, arg);
+		fprint(buf, "\n");
+		throw runtime_exception(buf.str());
 	}
 	var uintL value = cl_I_to_UL(arg);
 	struct roman { char symbol; uintL value; };
