@@ -16,13 +16,13 @@ namespace cln {
 void fprint (std::ostream& stream, const cl_ring& R, const cl_SV_ringelt& vector)
 {
 	var const cl_print_flags& flags = default_print_flags;
-	var uintL len = vector.length();
+	var uintC len = vector.length();
 	if (flags.vector_syntax == vsyntax_commonlisp) {
 		fprintchar(stream,'#');
 		fprintchar(stream,'(');
 	} else
 		fprintchar(stream,'[');
-	for (var uintL i = 0; i < len; i++) {
+	for (var uintC i = 0; i < len; i++) {
 		if (i > 0) {
 			if (flags.vector_syntax == vsyntax_algebraic)
 				fprintchar(stream,',');
